==> labs_cdk-0.0.2.tar.gz: labs_cdk-0.0.2/setup.py <==
import setuptools

with open("README.md") as fp:
    long_description = fp.read()

setuptools.setup(
    name="labs_cdk",
    version="0.0.2",
    author="Vaibhav Bansal",
    author_email="vaibhavbansal@gic.com.sg",
    description="GIC CSITR approved AWS CDK constructs",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/GICLabs/labs-cdk",
    package_dir={"": "labs_cdk"},
    packages=setuptools.find_packages(where="gic_cdk"),
    install_requires=[
        "attrs==19.3.0",
        "aws-cdk.assets==1.38.0",
        "aws-cdk.aws-apigateway==1.38.0",
        "aws-cdk.aws-applicationautoscaling==1.38.0",
        "aws-cdk.aws-autoscaling==1.38.0",
        "aws-cdk.aws-autoscaling-common==1.38.0",
        "aws-cdk.aws-autoscaling-hooktargets==1.38.0",
        "aws-cdk.aws-batch==1.38.0",
        "aws-cdk.aws-certificatemanager==1.38.0",
        "aws-cdk.aws-cloudformation==1.38.0",
        "aws-cdk.aws-cloudfront==1.38.0",
        "aws-cdk.aws-cloudwatch==1.38.0",
        "aws-cdk.aws-codebuild==1.38.0",
        "aws-cdk.aws-codecommit==1.38.0",
        "aws-cdk.aws-codepipeline==1.38.0",
        "aws-cdk.aws-cognito==1.38.0",
        "aws-cdk.aws-ec2==1.38.0",
        "aws-cdk.aws-ecr==1.38.0",
        "aws-cdk.aws-ecr-assets==1.38.0",
        "aws-cdk.aws-ecs==1.38.0",
        "aws-cdk.aws-ecs-patterns==1.38.0",
        "aws-cdk.aws-elasticache==1.38.0",
        "aws-cdk.aws-elasticloadbalancing==1.38.0",
        "aws-cdk.aws-elasticloadbalancingv2==1.38.0",
        "aws-cdk.aws-events==1.38.0",
        "aws-cdk.aws-events-targets==1.38.0",
        "aws-cdk.aws-iam==1.38.0",
        "aws-cdk.aws-kms==1.38.0",
        "aws-cdk.aws-lambda==1.38.0",
        "aws-cdk.aws-logs==1.38.0",
        "aws-cdk.aws-rds==1.38.0",
        "aws-cdk.aws-route53==1.38.0",
        "aws-cdk.aws-route53-targets==1.38.0",
        "aws-cdk.aws-s3==1.38.0",
        "aws-cdk.aws-s3-assets==1.38.0",
        "aws-cdk.aws-sam==1.38.0",
        "aws-cdk.aws-secretsmanager==1.38.0",
        "aws-cdk.aws-servicediscovery==1.38.0",
        "aws-cdk.aws-sns==1.38.0",
        "aws-cdk.aws-sns-subscriptions==1.38.0",
        "aws-cdk.aws-sqs==1.38.0",
        "aws-cdk.aws-ssm==1.38.0",
        "aws-cdk.aws-stepfunctions==1.38.0",
        "aws-cdk.cloud-assembly-schema==1.38.0",
        "aws-cdk.core==1.38.0",
        "aws-cdk.custom-resources==1.38.0",
        "aws-cdk.cx-api==1.38.0",
        "aws-cdk.region-info==1.38.0",
        "cattrs==1.0.0",
        "constructs==3.0.3",
        "jsii==1.5.0",
        "publication==0.0.3",
        "python-dateutil==2.8.1",
        "six==1.14.0",
        "typing-extensions==3.7.4.2"
    ],
    python_requires=">=3.6",
    classifiers=[
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
    ],
)

==> labs_cdk-0.0.3.tar.gz: labs_cdk-0.0.3/setup.py <==
import setuptools

with open("README.md") as fp:
    long_description = fp.read()

setuptools.setup(
    name="labs_cdk",
    version="0.0.3",
    author="Vaibhav Bansal",
    author_email="vaibhavbansal@gic.com.sg",
    description="GIC CSITR approved AWS CDK constructs",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/GICLabs/labs-cdk",
    package_dir={'': 'labs_cdk'},
    packages=setuptools.find_packages(where="labs_cdk"),
    install_requires=[
        "attrs==19.3.0",
        "aws-cdk.assets==1.38.0",
        "aws-cdk.aws-apigateway==1.38.0",
        "aws-cdk.aws-applicationautoscaling==1.38.0",
        "aws-cdk.aws-autoscaling==1.38.0",
        "aws-cdk.aws-autoscaling-common==1.38.0",
        "aws-cdk.aws-autoscaling-hooktargets==1.38.0",
        "aws-cdk.aws-batch==1.38.0",
        "aws-cdk.aws-certificatemanager==1.38.0",
        "aws-cdk.aws-cloudformation==1.38.0",
        "aws-cdk.aws-cloudfront==1.38.0",
        "aws-cdk.aws-cloudwatch==1.38.0",
        "aws-cdk.aws-codebuild==1.38.0",
        "aws-cdk.aws-codecommit==1.38.0",
        "aws-cdk.aws-codepipeline==1.38.0",
        "aws-cdk.aws-cognito==1.38.0",
        "aws-cdk.aws-ec2==1.38.0",
        "aws-cdk.aws-ecr==1.38.0",
        "aws-cdk.aws-ecr-assets==1.38.0",
        "aws-cdk.aws-ecs==1.38.0",
        "aws-cdk.aws-ecs-patterns==1.38.0",
        "aws-cdk.aws-elasticache==1.38.0",
        "aws-cdk.aws-elasticloadbalancing==1.38.0",
        "aws-cdk.aws-elasticloadbalancingv2==1.38.0",
        "aws-cdk.aws-events==1.38.0",
        "aws-cdk.aws-events-targets==1.38.0",
        "aws-cdk.aws-iam==1.38.0",
        "aws-cdk.aws-kms==1.38.0",
        "aws-cdk.aws-lambda==1.38.0",
        "aws-cdk.aws-logs==1.38.0",
        "aws-cdk.aws-rds==1.38.0",
        "aws-cdk.aws-route53==1.38.0",
        "aws-cdk.aws-route53-targets==1.38.0",
        "aws-cdk.aws-s3==1.38.0",
        "aws-cdk.aws-s3-assets==1.38.0",
        "aws-cdk.aws-sam==1.38.0",
        "aws-cdk.aws-secretsmanager==1.38.0",
        "aws-cdk.aws-servicediscovery==1.38.0",
        "aws-cdk.aws-sns==1.38.0",
        "aws-cdk.aws-sns-subscriptions==1.38.0",
        "aws-cdk.aws-sqs==1.38.0",
        "aws-cdk.aws-ssm==1.38.0",
        "aws-cdk.aws-stepfunctions==1.38.0",
        "aws-cdk.cloud-assembly-schema==1.38.0",
        "aws-cdk.core==1.38.0",
        "aws-cdk.custom-resources==1.38.0",
        "aws-cdk.cx-api==1.38.0",
        "aws-cdk.region-info==1.38.0",
        "cattrs==1.0.0",
        "constructs==3.0.3",
        "jsii==1.5.0",
        "publication==0.0.3",
        "python-dateutil==2.8.1",
        "six==1.14.0",
        "typing-extensions==3.7.4.2"
    ],
    python_requires=">=3.6",
    classifiers=[
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
    ],
)
